==> MetaMax-1.9.8.tar.gz: MetaMax/function.admin_metatab.php <==
<?php
if( !isset($gCms) ) exit;


// Get image files from /uploads/images
$files_list = Array($this->lang('none')=>"-1");
$dp = opendir($gCms->config['root_path'].'/uploads/images');
while ($file = readdir($dp)) {  
    if (strpos(substr($file, -5),'.gif') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.png') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.jpg') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.jpeg') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.ico') !== false) {
        $files_list[$file] = $file;
    }
}
closedir($dp);

// Get image files from root
$files_list_root = Array($this->lang('none')=>"-1");
$dp_root = opendir($gCms->config['root_path']);
while ($file_root = readdir($dp_root)) {  
    if (strpos(substr($file_root, -5),'.gif') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.png') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.jpg') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.jpeg') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.ico') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
}
closedir($dp_root);

$dropDown = array();
$dropDown[$this->Lang('drop_select')] = '-1';
$dropDown[$this->Lang('drop_yes')] = 'yes';
$dropDown[$this->Lang('drop_no')] = 'no';

$barStyle = array();
$barStyle[$this->Lang('style_select')] = '-1';
$barStyle[$this->Lang('style_default')] = 'default';
$barStyle[$this->Lang('style_black')] = 'black';
$barStyle[$this->Lang('style_translucent')] = 'black-translucent';

$robotsDrop = array();
$robotsDrop[$this->Lang('robots_default')] = '-1';
$robotsDrop[$this->Lang('robots_1')] = '0';
$robotsDrop[$this->Lang('robots_2')] = '1';
$robotsDrop[$this->Lang('robots_3')] = '2';

// CreateFormStart sets up a proper form tag that will cause the submit to
// return control to this module for processing.
$smarty->assign('startform', $this->CreateFormStart ($id, 'updatemeta', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());
$smarty->assign('submit', $this->CreateInputSubmit ($id, 'metasubmitbutton', $this->Lang('submit')));
$smarty->assign('legend_page_title',$this->Lang('page_title_legend'));
$smarty->assign('legend_meta_title',$this->Lang('meta_title_legend'));
$smarty->assign('legend_apple_title',$this->Lang('apple_title_legend'));
$smarty->assign('legend_metaoptions_title',$this->Lang('metaoptions_title_legend'));
$smarty->assign('page_title_help',$this->Lang('page_title_help'));
$smarty->assign('page_smarty_help',$this->Lang('page_smarty_help'));
$smarty->assign('delimiter_title_help',$this->Lang('delimiter_title_help'));
$smarty->assign('block_title_help',$this->Lang('block_title_help'));
$smarty->assign('canonical_block_title_help',$this->Lang('canonical_block_title_help'));
$smarty->assign('meta_block_title_help',$this->Lang('meta_block_title_help'));
$smarty->assign('content_var_title_help',$this->Lang('content_var_title_help'));
$smarty->assign('touchicon_root_title_help',$this->Lang('touchicon_root_title_help'));
$smarty->assign('touchicon_title_help',$this->Lang('touchicon_title_help'));
$smarty->assign('ogimage_title_help',$this->Lang('ogimage_title_help'));
$smarty->assign('ogtype_smarty_title_help',$this->Lang('ogtype_smarty_title_help'));
$smarty->assign('ogimage_smarty_title_help',$this->Lang('ogimage_smarty_title_help'));
$smarty->assign('favicon_root_title_help',$this->Lang('favicon_root_title_help'));
$smarty->assign('favicon_title_help',$this->Lang('favicon_title_help'));
$smarty->assign('favsize_title_help',$this->Lang('favsize_title_help'));
$smarty->assign('twittersite_title_help',$this->Lang('twittersite_title_help'));
$smarty->assign('googleplus_title_help',$this->Lang('googleplus_title_help'));

$smarty->assign('title_page_smarty',$this->Lang('page_smarty'));
$smarty->assign('input_page_smarty',$this->CreateInputText($id,'page_smarty',$this->GetPreference('page_smarty',''),50,255));

$smarty->assign('title_page_title',$this->Lang('page_title'));
$smarty->assign('input_page_title',$this->CreateInputText($id,'page_title',$this->GetPreference('page_title',''),50,255));

$smarty->assign('title_delimiter_title',$this->Lang('delimiter_title'));
$smarty->assign('input_delimiter_title',$this->CreateInputText($id,'delimiter_title',$this->GetPreference('delimiter_title','::'),10,15));

$smarty->assign('title_meta_block_title',$this->Lang('meta_block_title'));
$smarty->assign('input_meta_block_title',$this->CreateInputText($id,'meta_block_title',$this->GetPreference('meta_block_title',''),50,255));

$smarty->assign('title_content_var_title',$this->Lang('content_var_title'));
$smarty->assign('input_content_var_title',$this->CreateInputText($id,'content_var_title',$this->GetPreference('content_var_title',''),50,255));

$smarty->assign('title_block_title',$this->Lang('block_title'));
$smarty->assign('input_block_title',$this->CreateInputText($id,'block_title',$this->GetPreference('block_title',''),50,255));

$smarty->assign('title_canonical_block_title',$this->Lang('canonical_block_title'));
$smarty->assign('input_canonical_block_title',$this->CreateInputText($id,'canonical_block_title',$this->GetPreference('canonical_block_title',''),50,255));

$smarty->assign('title_auto_title',$this->Lang('auto_title'));
$smarty->assign('input_auto_title', $this->CreateInputCheckbox($id,'auto_title','1', $this->GetPreference('auto_title','1')));

$smarty->assign('title_length_title',$this->Lang('length_title'));
$smarty->assign('input_length_title',$this->CreateInputText($id,'length_title',$this->GetPreference('length_title','30'),10,255));

$smarty->assign('title_base_title',$this->Lang('base_title'));
$smarty->assign('input_base_title', $this->CreateInputCheckbox($id,'base_title','1', $this->GetPreference('base_title','1')));

$smarty->assign('title_standard_title',$this->Lang('standard_title'));
$smarty->assign('input_standard_title', $this->CreateInputCheckbox($id,'standard_title','1', $this->GetPreference('standard_title','1')));

$smarty->assign('title_dublin_title',$this->Lang('dublin_title'));
$smarty->assign('input_dublin_title', $this->CreateInputCheckbox($id,'dublin_title','1', $this->GetPreference('dublin_title','0')));

$smarty->assign('title_opengraph_title',$this->Lang('opengraph_title'));
$smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengraph_title','1', $this->GetPreference('opengraph_title','0')));

$smarty->assign('title_tweetme_title',$this->Lang('tweetme_title'));
$smarty->assign('input_tweetme_title', $this->CreateInputCheckbox($id,'tweetme_title','1', $this->GetPreference('tweetme_title','0')));

$smarty->assign('title_touchicon_root_title',$this->Lang('touchicon_root_title'));
$smarty->assign('input_touchicon_root_title',$this->CreateInputDropdown($id,'touchicon_root_title',$files_list_root,-1,$this->GetPreference('touchicon_root_title','')));

$smarty->assign('title_touchicon_title',$this->Lang('touchicon_title'));
$smarty->assign('input_touchicon_title',$this->CreateInputDropdown($id,'touchicon_title',$files_list,-1,$this->GetPreference('touchicon_title','')));

$smarty->assign('title_fullscreen_title',$this->Lang('fullscreen_title'));
$smarty->assign('input_fullscreen_title',$this->CreateInputDropdown($id,'fullscreen_title',$dropDown,$this->GetPreference('fullscreen_title','-1'),$this->GetPreference('fullscreen_title','-1')));

$smarty->assign('title_statusbar_title',$this->Lang('statusbar_title'));
$smarty->assign('input_statusbar_title',$this->CreateInputDropdown($id,'statusbar_title',$barStyle,$this->GetPreference('statusbar_title','-1'),$this->GetPreference('statusbar_title','-1')));

$smarty->assign('title_phoneno_title',$this->Lang('phoneno_title'));
$smarty->assign('input_phoneno_title',$this->CreateInputDropdown($id,'phoneno_title',$dropDown,$this->GetPreference('phoneno_title','-1'),$this->GetPreference('phoneno_title','-1')));

$smarty->assign('title_width_title',$this->Lang('width_title'));
$smarty->assign('input_width_title',$this->CreateInputText($id,'width_title',$this->GetPreference('width_title',''),10,255));

$smarty->assign('title_height_title',$this->Lang('height_title'));
$smarty->assign('input_height_title',$this->CreateInputText($id,'height_title',$this->GetPreference('height_title',''),10,255));

$smarty->assign('title_initial_title',$this->Lang('initial_title'));
$smarty->assign('input_initial_title',$this->CreateInputText($id,'initial_title',$this->GetPreference('initial_title',''),10,255));

$smarty->assign('title_minimum_title',$this->Lang('minimum_title'));
$smarty->assign('input_minimum_title',$this->CreateInputText($id,'minimum_title',$this->GetPreference('minimum_title',''),10,255));

$smarty->assign('title_maximum_title',$this->Lang('maximum_title'));
$smarty->assign('input_maximum_title',$this->CreateInputText($id,'maximum_title',$this->GetPreference('maximum_title',''),10,255));

$smarty->assign('title_scalable_title',$this->Lang('scalable_title'));
$smarty->assign('input_scalable_title',$this->CreateInputDropdown($id,'scalable_title',$dropDown,$this->GetPreference('scalable_title','-1'),$this->GetPreference('scalable_title','-1')));

$smarty->assign('title_robots_title',$this->Lang('robots_title'));
$smarty->assign('input_robots_title',$this->CreateInputDropdown($id,'robots_title',$robotsDrop,$this->GetPreference('robots_title','-1'),$this->GetPreference('robots_title','-1')));

$smarty->assign('title_publisher_title',$this->Lang('publisher_title'));
$smarty->assign('input_publisher_title',$this->CreateInputText($id,'publisher_title',$this->GetPreference('publisher_title',''),50,255));

$smarty->assign('title_contributor_title',$this->Lang('contributor_title'));
$smarty->assign('input_contributor_title',$this->CreateInputText($id,'contributor_title',$this->GetPreference('contributor_title',''),50,255));

$smarty->assign('title_email_title',$this->Lang('email_title'));
$smarty->assign('input_email_title',$this->CreateInputText($id,'email_title',$this->GetPreference('email_title',''),50,255));

$smarty->assign('title_phone_title',$this->Lang('phone_title'));
$smarty->assign('input_phone_title',$this->CreateInputText($id,'phone_title',$this->GetPreference('phone_title',''),50,255));

$smarty->assign('title_fax_title',$this->Lang('fax_title'));
$smarty->assign('input_fax_title',$this->CreateInputText($id,'fax_title',$this->GetPreference('fax_title',''),50,255));

$smarty->assign('title_relation_title',$this->Lang('relation_title'));
$smarty->assign('input_relation_title',$this->CreateInputText($id,'relation_title',$this->GetPreference('relation_title',''),50,255));

$smarty->assign('title_street_title',$this->Lang('street_title'));
$smarty->assign('input_street_title',$this->CreateInputText($id,'street_title',$this->GetPreference('street_title',''),50,255));

$smarty->assign('title_location_title',$this->Lang('location_title'));
$smarty->assign('input_location_title',$this->CreateInputText($id,'location_title',$this->GetPreference('location_title',''),50,255));

$smarty->assign('title_region_title',$this->Lang('region_title'));
$smarty->assign('input_region_title',$this->CreateInputText($id,'region_title',$this->GetPreference('region_title',''),10,5));

$smarty->assign('title_postcode_title',$this->Lang('postcode_title'));
$smarty->assign('input_postcode_title',$this->CreateInputText($id,'postcode_title',$this->GetPreference('postcode_title',''),50,255));

$smarty->assign('title_country_title',$this->Lang('country_title'));
$smarty->assign('input_country_title',$this->CreateInputText($id,'country_title',$this->GetPreference('country_title',''),10,5));

$smarty->assign('title_latitude_title',$this->Lang('latitude_title'));
$smarty->assign('input_latitude_title',$this->CreateInputText($id,'latitude_title',$this->GetPreference('latitude_title',''),50,255));

$smarty->assign('title_longitude_title',$this->Lang('longitude_title'));
$smarty->assign('input_longitude_title',$this->CreateInputText($id,'longitude_title',$this->GetPreference('longitude_title',''),50,255));

$smarty->assign('title_ogtype_title',$this->Lang('ogtype_title'));
$smarty->assign('input_ogtype_title',$this->CreateInputText($id,'ogtype_title',$this->GetPreference('ogtype_title','website'),50,255));

$smarty->assign('title_ogtype_smarty_title',$this->Lang('ogtype_smarty_title'));
$smarty->assign('input_ogtype_smarty_title',$this->CreateInputText($id,'ogtype_smarty_title',$this->GetPreference('ogtype_smarty_title',''),50,255));

$smarty->assign('title_ogimage_title',$this->Lang('ogimage_title'));
$smarty->assign('input_ogimage_title',$this->CreateInputDropdown($id,'ogimage_title',$files_list,-1,$this->GetPreference('ogimage_title','')));

$smarty->assign('title_ogimage_smarty_title',$this->Lang('ogimage_smarty_title'));
$smarty->assign('input_ogimage_smarty_title',$this->CreateInputText($id,'ogimage_smarty_title',$this->GetPreference('ogimage_smarty_title',''),50,255));

$smarty->assign('title_favicon_root_title',$this->Lang('favicon_root_title'));
$smarty->assign('input_favicon_root_title',$this->CreateInputDropdown($id,'favicon_root_title',$files_list_root,-1,$this->GetPreference('favicon_root_title','')));

$smarty->assign('title_favicon_title',$this->Lang('favicon_title'));
$smarty->assign('input_favicon_title',$this->CreateInputDropdown($id,'favicon_title',$files_list,-1,$this->GetPreference('favicon_title','')));

$smarty->assign('title_favsize_title',$this->Lang('favsize_title'));
$smarty->assign('input_favsize_title',$this->CreateInputText($id,'favsize_title',$this->GetPreference('favsize_title',''),50,255));

$smarty->assign('title_fbpage_title',$this->Lang('fbpage_title'));
$smarty->assign('input_fbpage_title',$this->CreateInputText($id,'fbpage_title',$this->GetPreference('fbpage_title',''),50,255));

$smarty->assign('title_fbadmin_title',$this->Lang('fbadmin_title'));
$smarty->assign('input_fbadmin_title',$this->CreateInputText($id,'fbadmin_title',$this->GetPreference('fbadmin_title',''),50,255));

$smarty->assign('title_fbapp_title',$this->Lang('fbapp_title'));
$smarty->assign('input_fbapp_title',$this->CreateInputText($id,'fbapp_title',$this->GetPreference('fbapp_title',''),50,255));

$smarty->assign('title_twittersite_title',$this->Lang('twittersite_title'));
$smarty->assign('input_twittersite_title',$this->CreateInputText($id,'twittersite_title',$this->GetPreference('twittersite_title',''),50,255));

$smarty->assign('title_googleplus_title',$this->Lang('googleplus_title'));
$smarty->assign('input_googleplus_title',$this->CreateInputText($id,'googleplus_title',$this->GetPreference('googleplus_title',''),50,255));

// Display the populated template
echo $this->ProcessTemplate ('adminmeta.tpl');

?>

==> MetaMax-1.9.9.5.tar.gz: MetaMax/function.admin_metatab.php <==
<?php
if( !isset($gCms) ) exit;


// Get image files from /uploads/images
$files_list = Array($this->lang('none')=>"-1");
$dp = opendir($gCms->config['root_path'].'/uploads/images');
while ($file = readdir($dp)) {  
    if (strpos(substr($file, -5),'.gif') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.png') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.jpg') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.jpeg') !== false) {
        $files_list[$file] = $file;
    }
    if (strpos(substr($file, -5),'.ico') !== false) {
        $files_list[$file] = $file;
    }
}
closedir($dp);

// Remove any files appended with thumb_
$files_list = array_filter($files_list, function ($var) {
	return (stripos($var, 'thumb_') === false);
});


// Get image files from root
$files_list_root = Array($this->lang('none')=>"-1");
$dp_root = opendir($gCms->config['root_path']);
while ($file_root = readdir($dp_root)) {  
    if (strpos(substr($file_root, -5),'.gif') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.png') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.jpg') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.jpeg') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
    if (strpos(substr($file_root, -5),'.ico') !== false) {
        $files_list_root[$file_root] = $file_root;
    }
}
closedir($dp_root);

// Remove any files appended with thumb_
$files_list_root = array_filter($files_list_root, function ($var) {
	return (stripos($var, 'thumb_') === false);
});


$dropDown = array();
$dropDown[$this->Lang('drop_select')] = '-1';
$dropDown[$this->Lang('drop_yes')] = 'yes';
$dropDown[$this->Lang('drop_no')] = 'no';

$barStyle = array();
$barStyle[$this->Lang('style_select')] = '-1';
$barStyle[$this->Lang('style_default')] = 'default';
$barStyle[$this->Lang('style_black')] = 'black';
$barStyle[$this->Lang('style_translucent')] = 'black-translucent';

$robotsDrop = array();
$robotsDrop[$this->Lang('robots_default')] = '-1';
$robotsDrop[$this->Lang('robots_1')] = '0';
$robotsDrop[$this->Lang('robots_2')] = '1';
$robotsDrop[$this->Lang('robots_3')] = '2';

// CreateFormStart sets up a proper form tag that will cause the submit to
// return control to this module for processing.
$smarty->assign('startform', $this->CreateFormStart ($id, 'updatemeta', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());
$smarty->assign('submit', $this->CreateInputSubmit ($id, 'metasubmitbutton', $this->Lang('submit')));
$smarty->assign('legend_page_title',$this->Lang('page_title_legend'));
$smarty->assign('legend_meta_title',$this->Lang('meta_title_legend'));
$smarty->assign('legend_apple_title',$this->Lang('apple_title_legend'));
$smarty->assign('legend_metaoptions_title',$this->Lang('metaoptions_title_legend'));
$smarty->assign('page_title_help',$this->Lang('page_title_help'));
$smarty->assign('page_smarty_help',$this->Lang('page_smarty_help'));
$smarty->assign('delimiter_title_help',$this->Lang('delimiter_title_help'));
$smarty->assign('block_title_help',$this->Lang('block_title_help'));
$smarty->assign('canonical_block_title_help',$this->Lang('canonical_block_title_help'));
$smarty->assign('meta_block_title_help',$this->Lang('meta_block_title_help'));
$smarty->assign('content_var_title_help',$this->Lang('content_var_title_help'));
$smarty->assign('touchicon_root_title_help',$this->Lang('touchicon_root_title_help'));
$smarty->assign('touchicon_title_help',$this->Lang('touchicon_title_help'));
$smarty->assign('ogimage_title_help',$this->Lang('ogimage_title_help'));
$smarty->assign('ogtype_smarty_title_help',$this->Lang('ogtype_smarty_title_help'));
$smarty->assign('ogimage_smarty_title_help',$this->Lang('ogimage_smarty_title_help'));
$smarty->assign('favicon_root_title_help',$this->Lang('favicon_root_title_help'));
$smarty->assign('favicon_title_help',$this->Lang('favicon_title_help'));
$smarty->assign('favsize_title_help',$this->Lang('favsize_title_help'));
$smarty->assign('twittersite_title_help',$this->Lang('twittersite_title_help'));
$smarty->assign('googleplus_title_help',$this->Lang('googleplus_title_help'));

$smarty->assign('title_page_smarty',$this->Lang('page_smarty'));
$smarty->assign('input_page_smarty',$this->CreateInputText($id,'page_smarty',$this->GetPreference('page_smarty',''),50,255));

$smarty->assign('title_page_title',$this->Lang('page_title'));
$smarty->assign('input_page_title',$this->CreateInputText($id,'page_title',$this->GetPreference('page_title',''),50,255));

$smarty->assign('title_delimiter_title',$this->Lang('delimiter_title'));
$smarty->assign('input_delimiter_title',$this->CreateInputText($id,'delimiter_title',$this->GetPreference('delimiter_title','::'),10,15));

$smarty->assign('title_meta_block_title',$this->Lang('meta_block_title'));
$smarty->assign('input_meta_block_title',$this->CreateInputText($id,'meta_block_title',$this->GetPreference('meta_block_title',''),50,255));

$smarty->assign('title_content_var_title',$this->Lang('content_var_title'));
$smarty->assign('input_content_var_title',$this->CreateInputText($id,'content_var_title',$this->GetPreference('content_var_title',''),50,255));

$smarty->assign('title_block_title',$this->Lang('block_title'));
$smarty->assign('input_block_title',$this->CreateInputText($id,'block_title',$this->GetPreference('block_title',''),50,255));

$smarty->assign('title_canonical_block_title',$this->Lang('canonical_block_title'));
$smarty->assign('input_canonical_block_title',$this->CreateInputText($id,'canonical_block_title',$this->GetPreference('canonical_block_title',''),50,255));

$smarty->assign('title_auto_title',$this->Lang('auto_title'));
$smarty->assign('input_auto_title', $this->CreateInputCheckbox($id,'auto_title','1', $this->GetPreference('auto_title','1')));

$smarty->assign('title_length_title',$this->Lang('length_title'));
$smarty->assign('input_length_title',$this->CreateInputText($id,'length_title',$this->GetPreference('length_title','30'),10,255));

$smarty->assign('title_base_title',$this->Lang('base_title'));
$smarty->assign('input_base_title', $this->CreateInputCheckbox($id,'base_title','1', $this->GetPreference('base_title','1')));

$smarty->assign('title_baseslash_title',$this->Lang('baseslash_title'));
$smarty->assign('input_baseslash_title', $this->CreateInputCheckbox($id,'baseslash_title','1', $this->GetPreference('baseslash_title','0')));

$smarty->assign('title_standard_title',$this->Lang('standard_title'));
$smarty->assign('input_standard_title', $this->CreateInputCheckbox($id,'standard_title','1', $this->GetPreference('standard_title','1')));

$smarty->assign('title_dublin_title',$this->Lang('dublin_title'));
$smarty->assign('input_dublin_title', $this->CreateInputCheckbox($id,'dublin_title','1', $this->GetPreference('dublin_title','0')));

$smarty->assign('title_opengraph_title',$this->Lang('opengraph_title'));
$smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengraph_title','1', $this->GetPreference('opengraph_title','0')));

$smarty->assign('title_tweetme_title',$this->Lang('tweetme_title'));
$smarty->assign('input_tweetme_title', $this->CreateInputCheckbox($id,'tweetme_title','1', $this->GetPreference('tweetme_title','0')));

$smarty->assign('title_touchicon_root_title',$this->Lang('touchicon_root_title'));
$smarty->assign('input_touchicon_root_title',$this->CreateInputDropdown($id,'touchicon_root_title',$files_list_root,-1,$this->GetPreference('touchicon_root_title','')));

$smarty->assign('title_touchicon_title',$this->Lang('touchicon_title'));
$smarty->assign('input_touchicon_title',$this->CreateInputDropdown($id,'touchicon_title',$files_list,-1,$this->GetPreference('touchicon_title','')));

$smarty->assign('title_fullscreen_title',$this->Lang('fullscreen_title'));
$smarty->assign('input_fullscreen_title',$this->CreateInputDropdown($id,'fullscreen_title',$dropDown,$this->GetPreference('fullscreen_title','-1'),$this->GetPreference('fullscreen_title','-1')));

$smarty->assign('title_statusbar_title',$this->Lang('statusbar_title'));
$smarty->assign('input_statusbar_title',$this->CreateInputDropdown($id,'statusbar_title',$barStyle,$this->GetPreference('statusbar_title','-1'),$this->GetPreference('statusbar_title','-1')));

$smarty->assign('title_phoneno_title',$this->Lang('phoneno_title'));
$smarty->assign('input_phoneno_title',$this->CreateInputDropdown($id,'phoneno_title',$dropDown,$this->GetPreference('phoneno_title','-1'),$this->GetPreference('phoneno_title','-1')));

$smarty->assign('title_width_title',$this->Lang('width_title'));
$smarty->assign('input_width_title',$this->CreateInputText($id,'width_title',$this->GetPreference('width_title',''),10,255));

$smarty->assign('title_height_title',$this->Lang('height_title'));
$smarty->assign('input_height_title',$this->CreateInputText($id,'height_title',$this->GetPreference('height_title',''),10,255));

$smarty->assign('title_initial_title',$this->Lang('initial_title'));
$smarty->assign('input_initial_title',$this->CreateInputText($id,'initial_title',$this->GetPreference('initial_title',''),10,255));

$smarty->assign('title_minimum_title',$this->Lang('minimum_title'));
$smarty->assign('input_minimum_title',$this->CreateInputText($id,'minimum_title',$this->GetPreference('minimum_title',''),10,255));

$smarty->assign('title_maximum_title',$this->Lang('maximum_title'));
$smarty->assign('input_maximum_title',$this->CreateInputText($id,'maximum_title',$this->GetPreference('maximum_title',''),10,255));

$smarty->assign('title_scalable_title',$this->Lang('scalable_title'));
$smarty->assign('input_scalable_title',$this->CreateInputDropdown($id,'scalable_title',$dropDown,$this->GetPreference('scalable_title','-1'),$this->GetPreference('scalable_title','-1')));

$smarty->assign('title_robots_title',$this->Lang('robots_title'));
$smarty->assign('input_robots_title',$this->CreateInputDropdown($id,'robots_title',$robotsDrop,$this->GetPreference('robots_title','-1'),$this->GetPreference('robots_title','-1')));

$smarty->assign('title_publisher_title',$this->Lang('publisher_title'));
$smarty->assign('input_publisher_title',$this->CreateInputText($id,'publisher_title',$this->GetPreference('publisher_title',''),50,255));

$smarty->assign('title_contributor_title',$this->Lang('contributor_title'));
$smarty->assign('input_contributor_title',$this->CreateInputText($id,'contributor_title',$this->GetPreference('contributor_title',''),50,255));

$smarty->assign('title_email_title',$this->Lang('email_title'));
$smarty->assign('input_email_title',$this->CreateInputText($id,'email_title',$this->GetPreference('email_title',''),50,255));

$smarty->assign('title_phone_title',$this->Lang('phone_title'));
$smarty->assign('input_phone_title',$this->CreateInputText($id,'phone_title',$this->GetPreference('phone_title',''),50,255));

$smarty->assign('title_fax_title',$this->Lang('fax_title'));
$smarty->assign('input_fax_title',$this->CreateInputText($id,'fax_title',$this->GetPreference('fax_title',''),50,255));

$smarty->assign('title_relation_title',$this->Lang('relation_title'));
$smarty->assign('input_relation_title',$this->CreateInputText($id,'relation_title',$this->GetPreference('relation_title',''),50,255));

$smarty->assign('title_street_title',$this->Lang('street_title'));
$smarty->assign('input_street_title',$this->CreateInputText($id,'street_title',$this->GetPreference('street_title',''),50,255));

$smarty->assign('title_location_title',$this->Lang('location_title'));
$smarty->assign('input_location_title',$this->CreateInputText($id,'location_title',$this->GetPreference('location_title',''),50,255));

$smarty->assign('title_region_title',$this->Lang('region_title'));
$smarty->assign('input_region_title',$this->CreateInputText($id,'region_title',$this->GetPreference('region_title',''),10,5));

$smarty->assign('title_postcode_title',$this->Lang('postcode_title'));
$smarty->assign('input_postcode_title',$this->CreateInputText($id,'postcode_title',$this->GetPreference('postcode_title',''),50,255));

$smarty->assign('title_country_title',$this->Lang('country_title'));
$smarty->assign('input_country_title',$this->CreateInputText($id,'country_title',$this->GetPreference('country_title',''),10,5));

$smarty->assign('title_latitude_title',$this->Lang('latitude_title'));
$smarty->assign('input_latitude_title',$this->CreateInputText($id,'latitude_title',$this->GetPreference('latitude_title',''),50,255));

$smarty->assign('title_longitude_title',$this->Lang('longitude_title'));
$smarty->assign('input_longitude_title',$this->CreateInputText($id,'longitude_title',$this->GetPreference('longitude_title',''),50,255));

$smarty->assign('title_ogtype_title',$this->Lang('ogtype_title'));
$smarty->assign('input_ogtype_title',$this->CreateInputText($id,'ogtype_title',$this->GetPreference('ogtype_title','website'),50,255));

$smarty->assign('title_ogtype_smarty_title',$this->Lang('ogtype_smarty_title'));
$smarty->assign('input_ogtype_smarty_title',$this->CreateInputText($id,'ogtype_smarty_title',$this->GetPreference('ogtype_smarty_title',''),50,255));

$smarty->assign('title_ogimage_title',$this->Lang('ogimage_title'));
$smarty->assign('input_ogimage_title',$this->CreateInputDropdown($id,'ogimage_title',$files_list,-1,$this->GetPreference('ogimage_title','')));

$smarty->assign('title_ogimage_smarty_title',$this->Lang('ogimage_smarty_title'));
$smarty->assign('input_ogimage_smarty_title',$this->CreateInputText($id,'ogimage_smarty_title',$this->GetPreference('ogimage_smarty_title',''),50,255));

$smarty->assign('title_favicon_root_title',$this->Lang('favicon_root_title'));
$smarty->assign('input_favicon_root_title',$this->CreateInputDropdown($id,'favicon_root_title',$files_list_root,-1,$this->GetPreference('favicon_root_title','')));

$smarty->assign('title_favicon_title',$this->Lang('favicon_title'));
$smarty->assign('input_favicon_title',$this->CreateInputDropdown($id,'favicon_title',$files_list,-1,$this->GetPreference('favicon_title','')));

$smarty->assign('title_favsize_title',$this->Lang('favsize_title'));
$smarty->assign('input_favsize_title',$this->CreateInputText($id,'favsize_title',$this->GetPreference('favsize_title',''),50,255));

$smarty->assign('title_fbpage_title',$this->Lang('fbpage_title'));
$smarty->assign('input_fbpage_title',$this->CreateInputText($id,'fbpage_title',$this->GetPreference('fbpage_title',''),50,255));

$smarty->assign('title_fbadmin_title',$this->Lang('fbadmin_title'));
$smarty->assign('input_fbadmin_title',$this->CreateInputText($id,'fbadmin_title',$this->GetPreference('fbadmin_title',''),50,255));

$smarty->assign('title_fbapp_title',$this->Lang('fbapp_title'));
$smarty->assign('input_fbapp_title',$this->CreateInputText($id,'fbapp_title',$this->GetPreference('fbapp_title',''),50,255));

$smarty->assign('title_twittersite_title',$this->Lang('twittersite_title'));
$smarty->assign('input_twittersite_title',$this->CreateInputText($id,'twittersite_title',$this->GetPreference('twittersite_title',''),50,255));

$smarty->assign('title_googleplus_title',$this->Lang('googleplus_title'));
$smarty->assign('input_googleplus_title',$this->CreateInputText($id,'googleplus_title',$this->GetPreference('googleplus_title',''),50,255));

// Display the populated template
echo $this->ProcessTemplate ('adminmeta.tpl');

?>
